Documentation
¶
Index ¶
- func ConvertSwaggerToOpenAPI(swaggerPath, outPath string) error
- func GenerateSwagDocsContent(routes []Route) string
- func LoadOpenAPI(path string) (*openapi3.T, error)
- func NormalizeEchoPath(path string) string
- func PatchSecuritySchemes(doc *openapi3.T)
- func ValidateRouteCoverage(doc *openapi3.T, routes []Route) error
- type Route
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConvertSwaggerToOpenAPI ¶
ConvertSwaggerToOpenAPI converts a swagger v2 file produced by swag into OpenAPI 3 and normalizes the security schemes for MCP consumption.
func GenerateSwagDocsContent ¶
GenerateSwagDocsContent returns the generated Swag annotations used as input to swag init.
func LoadOpenAPI ¶
LoadOpenAPI loads an OpenAPI 3 document from disk.
func NormalizeEchoPath ¶
NormalizeEchoPath converts Echo route params (:id) to OpenAPI params ({id}).
func PatchSecuritySchemes ¶
PatchSecuritySchemes rewrites the generated schemes into explicit bearer schemes.
Types ¶
Click to show internal directories.
Click to hide internal directories.